#
# spec file for package perl-MIME-Types
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name MIME-Types
Name:           perl-MIME-Types
Version:        2.260.0
Release:        2.1
%define cpan_version 2.26
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Definition of MIME types
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MA/MARKOV/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
Provides:       perl(MIME::Type) = %{version}
Provides:       perl(MIME::Types) = %{version}
Provides:       perl(MojoX::MIME::Types) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
MIME types are used in many applications (for instance as part of e-mail
and HTTP traffic) to indicate the type of content which is transmitted. or
expected. See RFC2045 at _https://www.ietf.org/rfc/rfc2045.txt_

Sometimes detailed knowledge about a mime-type is need, however this module
only knows about the file-name extensions which relate to some filetype. It
can also be used to produce the right format: types which are not
registered at IANA need to use 'x-' prefixes.

This object administers a huge list of known mime-types, combined from
various sources. For instance, it contains *all IANA* types and the
knowledge of Apache. Probably the most complete table on the net!

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc ChangeLog README README.md

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Wed Feb  7 2024 Tina Müller <timueller+perl@suse.de>
- updated to 2.26
  see /usr/share/doc/packages/perl-MIME-Types/ChangeLog
  version 2.26: Tue  6 Feb 10:08:33 CET 2024
  Changes:
  - iana updates
  version 2.25: Thu 29 Dec 10:27:24 CET 2022
  Improvements:
  - support multi-level extensions.  Flagged by [Michał Górny]
* Thu Dec 29 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.24
  see /usr/share/doc/packages/perl-MIME-Types/ChangeLog
  version 2.24: Wed 28 Dec 13:06:23 CET 2022
  Fixes:
  - vnd.gentoo officially took 'tar' and 'tbz2', but 'application/
  x-tar' resp 'x-gtar' prevails.  [Andreas Koenig]
  version 2.23: Thu 22 Dec 17:20:33 CET 2022
  Changes:
  - iana updates
* Thu Oct 28 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.22
  see /usr/share/doc/packages/perl-MIME-Types/ChangeLog
  version 2.22: Wed 27 Oct 16:54:38 CEST 2021
  Changes:
  - webm keeps on producting unexpected results [issue #11, Даша Федорова]
  - iana updates
* Sat May 29 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.21
  see /usr/share/doc/packages/perl-MIME-Types/ChangeLog
  version 2.21: Fri 28 May 12:01:00 CEST 2021
  Changes:
  - application/octet-stream is better for .dat [issue #11, Даша Федорова]
  - add video/webm which Google forgot to register [issue #12, Brent Laabs]
  - add image/webp which Google registered too late [issue #12, Brent Laabs]
* Fri Apr 23 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.20
  see /usr/share/doc/packages/perl-MIME-Types/ChangeLog
  version 2.20: Thu 22 Apr 12:48:35 CEST 2021
  Fixes:
  - problems with PAUSE cause the previous release to show-up in
  the wrong location.  Let's hope this release solves it.
  Changes:
  - heif/heic/heifs/heics/hif fix [issue #9, Даша Федорова]
  - no 'and' and 'or' extensions [issue #9, Даша Федорова]
  - application/octet-stream is better for .bin [issue #10, Даша Федорова]
* Sat Apr 17 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.19
  see /usr/share/doc/packages/perl-MIME-Types/ChangeLog
  version 2.19: Fri 16 Apr 11:47:10 CEST 2021
  Improvements:
  - update with the newest data from IANA and Apache httpd
  Changes:
  - mp4 preference is video/mp4 [issue #5, Даша Федорова]
  - yt preference is video/vnd.youtube.yt [issue #6, Даша Федорова]
  - 3gp and 3gpp preference is video/3gpp [issue #7, Даша Федорова]
* Fri Dec 11 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.18
  see /usr/share/doc/packages/perl-MIME-Types/ChangeLog
  version 2.18: Wed  9 Dec 10:29:46 CET 2020
  Improvements:
  - update with newest data
  Changes:
  - Mojo 6.0 changed types() into mapping() [Dmitry Latin ]
  - Mojo 7.94 adds experimental file_type()
  - Mojo 7.94 adds experimental content_type()
* Wed Feb  7 2018 coolo@suse.com
- updated to 2.17
  see /usr/share/doc/packages/perl-MIME-Types/ChangeLog
* Thu Nov  9 2017 coolo@suse.com
- updated to 2.14
  see /usr/share/doc/packages/perl-MIME-Types/ChangeLog
  version 2.14: Wed  8 Nov 17:45:22 CET 2017
  Fixes:
  - MojoX should not die on missing types.
  rt.cpan.org#123298 [Dmitry Latin]
* Tue Mar  8 2016 coolo@suse.com
- updated to 2.13
  see /usr/share/doc/packages/perl-MIME-Types/ChangeLog
  version 2.13: Mon  7 Mar 15:48:28 CET 2016
  Fixes:
  - not all information was extracted from the Apache tables.
  [Thomas Eckardt]
* Sat Nov 14 2015 coolo@suse.com
- updated to 2.12
  see /usr/share/doc/packages/perl-MIME-Types/ChangeLog
  version 2.12: Wed 11 Nov 12:24:55 CET 2015
  Improvements:
  - downgrade prereq perl to 5.6 [Peter Rabbitson]
  - update IANA
* Thu Jun 18 2015 coolo@suse.com
- updated to 2.11
  see /usr/share/doc/packages/perl-MIME-Types/ChangeLog
  version 2.11: Tue Jun 16 17:16:20 CEST 2015
  Improvements:
  - strict Perl 5.8
  rt.cpan.org #105267 [Miyagawa], cpantesters
* Tue Jun 16 2015 coolo@suse.com
- updated to 2.10
  see /usr/share/doc/packages/perl-MIME-Types/ChangeLog
  version 2.10: Mon Jun 15 17:32:22 CEST 2015
  Fixes:
  - accept field 'q' weights [Theo van Hoesel]
  Improvements:
  - introduce PERL_MIME_TYPE_DB
  rt.cpan.org#104945 [Philip Gwyn]
* Tue Apr 14 2015 coolo@suse.com
- updated to 2.09
  see /usr/share/doc/packages/perl-MIME-Types/ChangeLog
  version 2.09: Sun Sep 14 18:12:08 CEST 2014
  Improvements:
  - documentation use consistent parameter casing
  - do not use '//' to support 5.8.*
  rt.cpan.org#98664 [Paul]
* Tue Sep  9 2014 mardnh@gmx.de
- update to version 2.0.8
  - version 2.08: Fri Sep  5 15:29:52 CEST 2014
    Fixes:
  - fix test t/40mojo.t which mojo is not installed
    rt.cpan.org#98639 [Chris]
    Improvements:
  - remove dependency on Scalar::Util
  - documentation fixes
  - version 2.07: Fri Sep  5 12:08:06 CEST 2014
    Fixes:
  - MIME::Type::equals() did cmp not eq
    Improvements:
  - new httpAccept() wth tests in t/21accept.t
  - new httpAcceptBest() and httpAcceptSelect() with tests
    in t/22accbest.t
  - add MojoX::MIME::Types with tests in t/40mojo.t
  - now depends on List::Util and Scalar::Util
  - version 2.06: Thu Aug 28 16:28:43 CEST 2014
    Improvements:
  - needed other file from broofa :(
    rt.cpan.org#98308 [Lars Dɪᴇᴄᴋᴏᴡ]
  - fix scan of freedesktop definitions
    rt.cpan.org #98385 [Russell Jenkins]
* Wed Aug 27 2014 mardnh@gmx.de
- update to version 2.05:
    Improvements:
  - rename ::Type::isAscii() into ::Type::isText()
  - add source table broofa
    rt.cpan.org#98308 [Lars Dɪᴇᴄᴋᴏᴡ]
  - add source table freedesktop
    rt.cpan.org#98309 [Lars Dɪᴇᴄᴋᴏᴡ]
  - update iana types
* Mon Apr 21 2014 mardnh@gmx.de
- update to version 2.04
  - version 2.04: Thu Sep 12 15:46:28 CEST 2013
    Fixes:
  - one more localize $_ in ::Types::_read_db()
    rt.cpan.org#87856 [Gerda Shank]
  - version 2.03: Wed Sep  4 17:12:27 CEST 2013
    Improvements:
  - typo in docs, rt.cpan.org#88394 [Gregor Herrmann, Debian]
  - require perl 5.8.8, because <:encoding [cpantesters]
  - updated IANA
  - a bit more DESCRIPTION
  - version 2.02: Sun Aug 18 12:49:23 CEST 2013
    Fixes:
  - localize DB and $_ in ::Types::_read_db()
    rt.cpan.org#87856 [Gerda Shank]
  - version 2.01: Sat Aug  3 01:07:27 CEST 2013
    Improvements:
  - add dummy ::Types::create_type_index() because
    Catalyst-Plugin-Static-Simple calls it :(
  - version 2.00: Fri Aug  2 17:44:53 CEST 2013
    Changes:
  - the mime information is now collected from various sources, amongst
    them IANA.  Therefore, some types may use different x-'s
    [#]types up from 995 to 2096
  - a separate table is built for the extension-to-type mapping.
    [#]exts  up from 734 to 1425
  - the memory foot-print and start-up speed should have improved
    considerably.
    Improvements:
  - added bin/collect_types
  - 3 typos. rt.cpan.org#86847 [D Steinbrunner]
  - add ::Type::isVendor(), ::isExperimental(), ::isPersonal on request
    by rt.cpan.org#87062 [Lars Dɪᴇᴄᴋᴏᴡ 迪拉斯]
  - cleaned-up Exporter syntax of (very) old interface.
  - added ::Types::listTypes()
  - version 1.38: Fri Jan 11 09:58:08 CET 2013
  - add application/vnd.ms-excel.template.macroEnabled.12 and five
    related from http://filext.com/faq/office_mime_types.php
    rt.cpan.org#82616 [M Jemmeson]
  - version 1.37: Fri Dec 21 11:33:53 CET 2012:
  - all mime.types files agree that perl scripts should use
    application/x-perl.  Hence removed text/x-perl
    rt.cpan.org#82100 [Kent Fredric]
  - version 1.36: Wed Oct 31 20:34:42 CET 2012
  - xlsx and friends had encoding 'binary' (since version 1.30),
    but should have been 'base64'
    rt.cpan.org#80529 [Douglas Wilson]
  - version 1.35: Tue Jun 19 20:37:21 CEST 2012
  - added video/webm and audio/webm, although not (yet) IANA registered.
    [Kurian Jose Aerthail]
* Fri Jan 13 2012 vcizek@suse.com
- update to 1.34
  - subType() did not handle subType's with '+' in them.
  [Roman V. Nikolaev]
  - all openxmlformats are binary [Beverly Wang]
  - mediaType() and subType() did not handle subType's with dots
  in them correctly. [Roman V. Nikolaev]
* Mon Aug 29 2011 vcizek@suse.com
- update to 1.32
  - explain how to use MIME::Types in mod_perl, after complains
  from [Steve Simms], [Nicolas Mendoza], [Yves Orton] and
  [Hans Dieter Pearcey]
  - when you do not read the documentation about mod_perl/fork,
  then it will work as ever but still inefficient.
- licence correction
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Thu Sep 23 2010 anicka@suse.cz
- update to 1.31
  * moved POD test to xt directory, reducing the number of
  dependencies.
* Fri Jul 16 2010 anicka@suse.cz
- update to 1.30
  * typo.  rt.cpan.org#55655 [Salvatore.Bonaccorso]
  * xlsx must be encoded binary [Ben Prew]
  * added f4v, f4p, f4a, f4b extensions for mpeg4
  rt.cpan.org#55168 [Oskari Ojala]
* Thu Mar 25 2010 anicka@suse.cz
- update to 1.29
  * added a zillions of new types from debian's /etc/mime.types.
  implemented by [Roman V. Nikolaev]
  * changed table format, hopefully to speed-up load times per
  type, slightly compensating for the increased list.
* Wed Jan 13 2010 anicka@suse.cz
- update to 1.28
  * fix initiation when using by_mediatype().
  rt.cpan.org#49111 [GENEHACK]
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Fri Feb 27 2009 anicka@suse.cz
- update to 1.27
  * fix application/ogg to .ogx.
  * alternative for ogg in test scripts
  * test by_mediatype with regexp parameter.
  * do not use /bin/pwd in t/pod.t
* Tue Jan 20 2009 anicka@suse.cz
- update to 1.26
  * added many ooxml types
  * added application/jsoni
  * added text/x-component
* Thu Jun 19 2008 anicka@suse.cz
- update to 1.24
  * message/rfc822 relates to .eml
  * application/vnd.openxmlformats-officedocument.spreadsheetml.sheet
  is an .xlsx
  * added zillion of application/vnd.oasis.opendocument.* and
  application/vnd.stardevision.* names
* Fri Jan  4 2008 anicka@suse.cz
- update to 1.23
  * /xml file attributes were separated by blanks, not commas.
* Wed Nov 21 2007 anicka@suse.cz
- update to 1.22
  * use RFC4180 text/csv, not text/comma-separated-values
  * refer to File::TypeInfo for access to mime.types files.
* Mon Oct  8 2007 anicka@suse.cz
- update to 1.21
  * patch tests to work on VMS
  * patch for image/pjpeg bug IE6
* Mon Jun 11 2007 anicka@suse.cz
- update to 1.20
  * added application/xslt+xml (.xslt)
  * moved extension .xml from text/xml (deprecated) to
    application/xml, and added .xsl to it
  * Moved .dtd from text/xml to application/xml-dtd
  * added t/pod.t
- enable tests
* Fri Mar 30 2007 anicka@suse.cz
- update to 1.19
  * converted to use OODoc 0.99
  * removed mkdist, mkdoc, README.oodoc, version
* Wed Dec 13 2006 anicka@suse.cz
- update to 1.18
  * application/atom+xml and image/svg+xml
  * audio/3gpp2 and video/3gpp2
  * application/octet-stream += dmg, so, dll
    and videa/x-flv.
* Wed Sep 13 2006 anicka@suse.cz
- update to 1.17
  * application/rdf+xml
  * reprocessed manual-pages because FUNCTIONS chapers was lost
  * use 'version' file for version
  * added kml and kmz types by Google-Earth
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan  3 2006 anicka@suse.cz
- update 1.16
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Mon Aug  1 2005 cthiel@suse.de
- update to version 1.15
* Thu Feb 26 2004 mjancar@suse.cz
- update to 1.12
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Tue Jul 15 2003 freitag@suse.de
- fixed spec-file: Used macros in installation and filelist
* Fri Jun 13 2003 freitag@suse.de
- update to version 1.06 - no real changes, but now it is a stable
  release. Some more Mimetypes were added.
* Fri Jun 13 2003 freitag@suse.de
- fixed spec file (directories not listed)
* Sun May 25 2003 ro@suse.de
- remove unpackaged files from buildroot
* Thu Aug  8 2002 mls@suse.de
- use sitearch macro
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Mon Apr  8 2002 freitag@suse.de
- new package with initial version 0.16, required by pdb
